@@ -18,7 +18,7 @@ def runMigrationsForStorageContext(storageContext: ObjectStorageContext):
 
     # Alembic requires a DB to read the version from. We mock an in-memory DB
     # that has a table `alembic_version` with a single value as the current rev
-    db = sqlite3.connect("file::memory:")
+    db = sqlite3.connect("file:")
     cur = db.cursor()
     cur.execute("CREATE TABLE alembic_version(version_num varchar)")
     # What if someone sets currentRev to "Robert'); DROP TABLE users;--" ?
@@ -29,7 +29,7 @@ def runMigrationsForStorageContext(storageContext: ObjectStorageContext):
 
     # Since sqlite3 can have only one memory DB per thread, this `:memory:` DB
     # will be the same as the one created previously
-    engine = create_engine("sqlite:///:memory:")
+    engine = create_engine("sqlite:///")
 
     # Load the migration scripts and
     codeDir = os.path.dirname(os.path.realpath(__file__))
